<script setup lang="ts">
import TitlePanel from "@/views/ecg/doctor/components/TitlePanel.vue";
import QueuePanel from "@/views/ecg/doctor/components/QueuePanel.vue";
import {DoctorApi, PatientStatisticVO, RoomBedVO} from '@/api/ecg/doctor';
import {useUserStore} from "@/store/modules/user";
import {queueApi, queueVO} from "@/api/ecg/queue";

const userStore = useUserStore();

const roomBedVO: RoomBedVO = {
    roomId: userStore.room!.roomId,
    bedNo: userStore.room!.bedNo
}

const patientStat = ref<PatientStatisticVO>({
    finishedNum: 0,
    readyNum: 0,
    passedNum: 0,
    queuingNum: 0
})

const state = ref<boolean>(true)

const list = ref<queueVO[]>([])

const finishNextPatient = async () => {
  list.value = await DoctorApi.finishNextPatient(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
}

const passNextPatient = async () => {
  list.value = await DoctorApi.passNextPatient(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
}

const getPatientList = async () => {
  list.value = await DoctorApi.getPatientList(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
}

const pauseQueue = async () => {
  state.value = false
  queueApi.bedDoctorPause(roomBedVO)
}

const resumeQueue = async () => {
  state.value = true
  queueApi.bedDoctorResume(roomBedVO)
}

/** 初始化 **/
onMounted(() => {
    getPatientList()
})

</script>

<template>
  <el-container>
    <el-header style="background-color: var(--el-color-primary-light-7); font-size: 24px">
      <TitlePanel :patientStatistic="patientStat" />
    </el-header>
    <el-container>
      <el-main>
        装机界面
      </el-main>
      <el-aside width="300px" style="background-color: var(--el-color-primary-light-7);">
        <QueuePanel :queue="list"/>
      </el-aside>
    </el-container>
    <el-container style="justify-content: center; margin-top: 30px">
      <el-button type="primary" @click="finishNextPatient">叫号</el-button>
      <el-button type="primary" @click="passNextPatient">过号</el-button>
      <el-button v-if="state" type="primary" @click="pauseQueue">暂停</el-button>
      <el-button v-else type="primary" @click="resumeQueue">恢复</el-button>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">

</style>
